(v1.8.2)=
### 1.8.2 {small}`2021-11-3`

#### Documentation

- Update conda installation instructions {pr}`1974` {smaller}`L Heumos`

#### Bug fixes

- Fix plotting after {func}`scanpy.tl.filter_rank_genes_groups` {pr}`1942` {smaller}`S Rybakov`
- Fix `use_raw=None` using {attr}`anndata.AnnData.var_names` if {attr}`anndata.AnnData.raw`
  is present in {func}`scanpy.tl.score_genes` {pr}`1999` {smaller}`M Klein`
- Fix compatibility with UMAP 0.5.2 {pr}`2028` {smaller}`L Mcinnes`
- Fixed non-determinism in {func}`scanpy.pl.paga` node positions {pr}`1922` {smaller}`I Virshup`

#### Ecosystem

- Added PASTE (a tool to align and integrate spatial transcriptomics data) to scanpy ecosystem.
